@@ -695,7 +695,6 @@ class frmRecordWindow(QMainWindow):
         if(data.run==True): #recording
             t=time.mktime(time.localtime())
             time_difference=t-data.StartTimeSec
-#            d=time.strftime("%X", time.gmtime(time_difference))
             d=time.strftime("%H:%M:%S", time.gmtime(time_difference))
             self.ui.lblElapsedTime.setText("Elapsed time: "+d + " ("+str(records.Index)+" entries)")
         else: self.UpdateScreenStop()
@@ -1552,10 +1551,10 @@ class frmAdditionalInfoWindow(QMainWindow):
          
         txt=txt+"<b>Statistics:</b><table>\n" + \
                 "<tr><td><b>Sleep phase: </b></td>   <td><b>Total time: </b></td>                                     <td><b>Longest time:</b></td>                                    <td><b>Count: </b></td>                     <td colspan=2><b>Time percent:</b></td>\n" + \
-                "<tr><td><b>Awake:</b></td>         <td>"+strftime("%X", time.gmtime(records.arrStatData[3][0]))+"</td>    <td>-</td>    <td>-</td>    <td>"+str(records.arrStatData[3][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State4.png"+"\" width="+str(records.arrStatData[3][3]*2)+" height=25</td></tr>\n" + \
-                "<tr><td><b>Light:</b></td>         <td>"+strftime("%X", time.gmtime(records.arrStatData[2][0]))+"</td>    <td>"+strftime("%X", time.gmtime(records.arrStatData[2][2]))+"</td>    <td>"+str(records.arrStatData[2][1])+"</td>    <td>"+str(records.arrStatData[2][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State3.png"+"\" width="+str(records.arrStatData[2][3]*2)+" height=25</td></tr>\n" + \
-                "<tr><td><b>Middle:</b></td>        <td>"+strftime("%X", time.gmtime(records.arrStatData[1][0]))+"</td>    <td>"+strftime("%X", time.gmtime(records.arrStatData[1][2]))+"</td>    <td>"+str(records.arrStatData[1][1])+"</td>    <td>"+str(records.arrStatData[1][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State2.png"+"\" width="+str(records.arrStatData[1][3]*2)+" height=25</td></tr>\n" + \
-                "<tr><td><b>Deep:</b></td>          <td>"+strftime("%X", time.gmtime(records.arrStatData[0][0]))+"</td>    <td>"+strftime("%X", time.gmtime(records.arrStatData[0][2]))+"</td>    <td>"+str(records.arrStatData[0][1])+"</td>    <td>"+str(records.arrStatData[0][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State1.png"+"\" width="+str(records.arrStatData[0][3]*2)+" height=25</td></tr>\n" + \
+                "<tr><td><b>Awake:</b></td>         <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[3][0]))+"</td>    <td>-</td>    <td>-</td>    <td>"+str(records.arrStatData[3][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State4.png"+"\" width="+str(records.arrStatData[3][3]*2)+" height=25</td></tr>\n" + \
+                "<tr><td><b>Light:</b></td>         <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[2][0]))+"</td>    <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[2][2]))+"</td>    <td>"+str(records.arrStatData[2][1])+"</td>    <td>"+str(records.arrStatData[2][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State3.png"+"\" width="+str(records.arrStatData[2][3]*2)+" height=25</td></tr>\n" + \
+                "<tr><td><b>Middle:</b></td>        <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[1][0]))+"</td>    <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[1][2]))+"</td>    <td>"+str(records.arrStatData[1][1])+"</td>    <td>"+str(records.arrStatData[1][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State2.png"+"\" width="+str(records.arrStatData[1][3]*2)+" height=25</td></tr>\n" + \
+                "<tr><td><b>Deep:</b></td>          <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[0][0]))+"</td>    <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[0][2]))+"</td>    <td>"+str(records.arrStatData[0][1])+"</td>    <td>"+str(records.arrStatData[0][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State1.png"+"\" width="+str(records.arrStatData[0][3]*2)+" height=25</td></tr>\n" + \
               "</table><br><br>\n"
         
         txt=txt+"<b>Sampling interval:</b> "+str(records.Sampling_interval) + " ms<br>" + \
